# Directory Contents

This directory contains the data generated by using the convolution functions in `tcms_as_convolutions.py`. The data is essentially a makeshift database of TACs (Time Activity Curves) for various models. The TACs are essential components in understanding and modelling the kinetics of radiotracers in PET (Positron Emission Tomography).

Currently[^1], we have data for:
* 1TCM in `1tcm`
  * $k_{1}=1.00;$ $k_{2}=0.25$
  * $k_{1}=0.25;$ $k_{2}=1.00$
* Serial 2TCM with $k_4=0$ in `serial_2tcm_k4zero`
  * $k_{1}=0.50;$ $k_{2}=0.50;$ $k_{3}=0.01$
  * $k_{1}=0.50;$ $k_{2}=0.50;$ $k_{3}=0.25$
* Serial 2TCM in `serial_2tcm`
  * $k_{1}=0.50;$ $k_{2}=0.85;$ $k_{3}=0.01;$ $k_{4}=0.01$
  * $k_{1}=0.50;$ $k_{2}=0.85;$ $k_{3}=0.25;$ $k_{4}=0.01$
  * $k_{1}=0.50;$ $k_{2}=0.85;$ $k_{3}=0.25;$ $k_{4}=0.15$
  
Additionally, the directories include plots corresponding to different test data sets. These plots provide a visual representation of the TACs.

In these directories, you will find two versions of the TACs:

1. **Noise-less TACs**: These are TACs that have been processed without the addition of any noise. They depict the ideal data, assuming perfect experimental conditions.

2. **TACs with Gaussian Noise**: These TACs have been artificially modified with Gaussian noise. The variance of this noise is determined by the average value of counts in the input TAC. Explicitly, we have:

$$
\sigma = \frac{\int_{t_0}^{t^n}C_\mathrm{P}(t)\mathrm{d}t}{t_n - t_0},
$$

The inclusion of both versions of TACs allows for a more robust analysis of the models and their performance under various conditions. 

[^1]: The model names and parameters used are also in JSON files.